@@ -10,11 +10,11 @@ import django.core.handlers.wsgi
 sys.path.insert(0, '/home/mario/stuff/__orbited/demos/python')
 
 
-def main(port):
+def main(**kwargs):
     # the name of the django app is "djangochat"
     os.environ["DJANGO_SETTINGS_MODULE"] = "djangochat.settings"
     application = django.core.handlers.wsgi.WSGIHandler()    
-    server = HTTPApplication("", port)
+    server = HTTPApplication("", kwargs['port'])
     
     # forward any traffic starting with '/' to the application
     # Note: in this case, that means all urls are sent to django
